==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/cs.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerie",
    "There was a problem reading files from this album" : "Nastal problém při čtení souborů z tohoto alba",
    "Aborting preview. Could not find the file" : "Načítání náhledu ukončeno. Soubor nelze nalézt",
    "Could not move \"{file}\", target exists" : "Nelze přesunout \"{file}\", cíl existuje",
    "Could not move \"{file}\"" : "Nelze přesunout \"{file}\"",
    "No compatible server found at {remote}" : "Na {remote} nebyl nalezen kompatibilní server",
    "Invalid server url" : "Neplatné URL serveru",
    "Could not load the description" : "Nezdařilo se načíst popis",
    "Could not load the description: " : "Nezdařilo se načíst popis:",
    "Copyright" : "Autorská práva",
    "Could not load the copyright notice: " : "Nelze načíst informace o autorských právech:",
    "Copyright notice" : "Informace o autorských právech",
    "Link to copyright document" : "Odkaz na dokument s autorskými právy",
    "This application may not work properly on your browser." : "Tato aplikace nemusí pracovat správně ve vašem prohlížeči.",
    "For an improved experience, please install one of the following alternatives" : "Pro zlepšení uživatelské přívětivosti prosím nainstalujte jednu z dostupných alternativ",
    "Your browser is not supported!" : "Tento prohlížeč není podporován!",
    "please install one of the following alternatives" : "nainstalujte prosím jednu z následujících alternativ",
    "Album cannot be shown" : "Album nelze zobrazit",
    "No media files found" : "Nenalezeny žádné multimediální soubory",
    "Upload pictures in the Files app to display them here" : "Pro zobrazení obrázků v tomto náhledu nějaké nahrajte přes aplikaci soubory",
    "Upload new files via drag and drop or by using the [+] button above" : "Nahrajte nové soubory pomocí přetažení, nebo za použití tlačítka [+] výše",
    "Configuration error" : "Chyba konfigurace",
    "New" : "Nový",
    "Hide Album" : "Skrýt album",
    "Could not hide album" : "Nepodařilo se skrýt album",
    "Error loading slideshow template" : "Chyba při načítání šablony prezentace",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Chyba!</strong> Náhled tohoto souboru nelze vytvořit.<br>Přejděte prosím na následující položku a tento obrázek bude odstraněn ze slideshow",
    "Next" : "Následující",
    "Play" : "Přehrát",
    "Pause" : "Pozastavit",
    "Previous" : "Předchozí",
    "Close" : "Zavřít",
    "Download" : "Stáhnout",
    "Toggle background" : "Přepnout pozadí",
    "Delete" : "Smazat",
    "Share" : "Sdílet",
    "Could not create file \"{file}\" because it already exists" : "Nelze vytvořit soubor \"{file}\", protože již existuje",
    "Could not create file \"{file}\"" : "Nelze vytvořit soubor \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatným názvem souboru.",
    "File name cannot be empty." : "Název souboru nemůže být prázdný řetězec.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" není povolený typ souboru",
    "Upload" : "Nahrát",
    "Error" : "Chyba",
    "Error while sharing" : "Chyba při sdílení",
    "Error while unsharing" : "Chyba při rušení sdílení",
    "Error while changing permissions" : "Chyba při změně oprávnění",
    "Shared with you and the group {group} by {owner}" : "S Vámi a skupinou {group} sdílí {owner}",
    "Shared with you by {owner}" : "S Vámi sdílí {owner}",
    "Share with users or groups …" : "Sdílet s uživateli nebo skupinami",
    "Share with users, groups or remote users …" : "Sdílet s uživateli, skupinami nebo vzdálenými uživateli",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Sdílet s uživateli na jiných serverech za použití jejich sdílených cloud ID username@example.com/cloud",
    "Share link" : "Sdílet odkaz",
    "The public link will expire no later than {days} days after it is created" : "Veřejný odkaz vyprší nejpozději {days} dní od svého vytvoření",
    "Link" : "Odkaz",
    "Password protect" : "Chránit heslem",
    "Password" : "Heslo",
    "Choose a password for the public link" : "Zadej heslo pro tento veřejný odkaz",
    "Allow editing" : "Povolit úpravy",
    "Email link to person" : "Odeslat osobě odkaz emailem",
    "Send" : "Odeslat",
    "Set expiration date" : "Nastavit datum vypršení platnosti",
    "Expiration" : "Konec platnosti",
    "Expiration date" : "Datum vypršení platnosti",
    "This list is maybe truncated - please refine your search term to see more results." : "Tento seznam je možná zkrácený - prosím upřesněte vyhledávací výraz pro více výsledků.",
    "No users or groups found for {search}" : "Nebyli nalezeni žádní členové ani skupiny pro {search}",
    "No users found for {search}" : "Nebyli nalezeni žádní uživatelé pro {search}",
    "An error occured. Please try again" : "Nastala chyba. Prosím zkuste to znovu",
    "Adding user..." : "Přidávám uživatele...",
    "group" : "skupina",
    "remote" : "vzdálený",
    "Resharing is not allowed" : "Sdílení již sdílené položky není povoleno",
    "Error while retrieving shares" : "Chyba při otevírání sdílení",
    "Unshare" : "Zrušit sdílení",
    "notify by email" : "upozornit emailem",
    "can share" : "může sdílet",
    "can edit" : "lze upravovat",
    "access control" : "řízení přístupu",
    "create" : "vytvořit",
    "change" : "změnit",
    "delete" : "smazat",
    "Password protected" : "Chráněno heslem",
    "Error unsetting expiration date" : "Chyba při odstraňování data vypršení platnosti",
    "Error setting expiration date" : "Chyba při nastavení data vypršení platnosti",
    "Sending ..." : "Odesílám ...",
    "Email sent" : "Email odeslán",
    "Warning" : "Varování",
    "This share is password-protected" : "Toto sdílení je chráněno heslem",
    "The password is wrong. Try again." : "Heslo není správné. Zkuste to znovu.",
    "Sort by name" : "Řadit podle jména",
    "Sort by date" : "Řadit podle data",
    "Cancel upload" : "Zrušit odesílání",
    "Album information" : "Informace o albu",
    "File list" : "Seznam souborů",
    "Sorry, this file could not be found." : "Omlouváme se, tento soubor se nepodařilo nalézt.",
    "Reasons might be:" : "Možné důvody:",
    "the wrong file ID was provided" : "bylo zadáno neplatné ID souboru",
    "the file was removed" : "soubor byl odstraněn",
    "the file is corrupt" : "soubor je poškozen",
    "the encryption key is missing" : "chybí šifrovací klíč",
    "Here is the error message returned by the server: " : "Zde je chybová zpráva vrácená serverem:",
    "For more information, please contact your friendly Nextcloud administrator." : "Pokud chcete vědět víc, kontaktujte svého přátelského administrátora  Nextcloudu.",
    "Sorry, but the server could not fulfill your request." : "Omlouváme se, ale server nemohl splnit váš požadavek.",
    "Possible reasons for the problem:" : "Možný důvod problému:",
    "a conflicting app was installed" : "byla nainstalovaná konfliktní aplikace",
    "a required component is missing or was disconnected" : "chybí nebo je odpojena požadovaná část systému",
    "the filesystem is not readable" : "nelze čist ze souborového systému",
    "Sorry, this link doesn't seem to work anymore." : "Omlouváme se, tento odkaz je již nejspíše nefunkční.",
    "the item was removed" : "položka byla odebrána",
    "the link has expired" : "platnost odkazu vypršela",
    "sharing is disabled" : "sdílení je zakázané",
    "For more information, please ask the person who has sent you this link." : "Pro více informací kontaktujte osobu, která vám zaslala tento odkaz.",
    "Add to your Nextcloud" : "Přidat do Nextcloud",
    "Picture view" : "Zobrazení obrázku",
    "Gallery view" : "Náhled galerie"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/cs.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerie",
    "There was a problem reading files from this album" : "Nastal problém při čtení souborů z tohoto alba",
    "Aborting preview. Could not find the file" : "Načítání náhledu ukončeno. Soubor nelze nalézt",
    "Could not move \"{file}\", target exists" : "Nelze přesunout \"{file}\", cíl existuje",
    "Could not move \"{file}\"" : "Nelze přesunout \"{file}\"",
    "No compatible server found at {remote}" : "Na {remote} nebyl nalezen kompatibilní server",
    "Invalid server url" : "Neplatné URL serveru",
    "Could not load the description" : "Nezdařilo se načíst popis",
    "Could not load the description: " : "Nezdařilo se načíst popis:",
    "Copyright" : "Autorská práva",
    "Could not load the copyright notice: " : "Nelze načíst informace o autorských právech:",
    "Copyright notice" : "Informace o autorských právech",
    "Link to copyright document" : "Odkaz na dokument s autorskými právy",
    "This application may not work properly on your browser." : "Tato aplikace nemusí pracovat správně ve vašem prohlížeči.",
    "For an improved experience, please install one of the following alternatives" : "Pro zlepšení uživatelské přívětivosti prosím nainstalujte jednu z dostupných alternativ",
    "Your browser is not supported!" : "Tento prohlížeč není podporován!",
    "please install one of the following alternatives" : "nainstalujte prosím jednu z následujících alternativ",
    "Album cannot be shown" : "Album nelze zobrazit",
    "No media files found" : "Nenalezeny žádné multimediální soubory",
    "Upload pictures in the Files app to display them here" : "Pro zobrazení obrázků v tomto náhledu nějaké nahrajte přes aplikaci soubory",
    "Upload new files via drag and drop or by using the [+] button above" : "Nahrajte nové soubory pomocí přetažení, nebo za použití tlačítka [+] výše",
    "Configuration error" : "Chyba konfigurace",
    "New" : "Nový",
    "Hide Album" : "Skrýt album",
    "Could not hide album" : "Nepodařilo se skrýt album",
    "Error loading slideshow template" : "Chyba při načítání šablony prezentace",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Chyba!</strong> Náhled tohoto souboru nelze vytvořit.<br>Přejděte prosím na následující položku a tento obrázek bude odstraněn ze slideshow",
    "Next" : "Následující",
    "Play" : "Přehrát",
    "Pause" : "Pozastavit",
    "Previous" : "Předchozí",
    "Close" : "Zavřít",
    "Download" : "Stáhnout",
    "Toggle background" : "Přepnout pozadí",
    "Delete" : "Smazat",
    "Share" : "Sdílet",
    "Could not create file \"{file}\" because it already exists" : "Nelze vytvořit soubor \"{file}\", protože již existuje",
    "Could not create file \"{file}\"" : "Nelze vytvořit soubor \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatným názvem souboru.",
    "File name cannot be empty." : "Název souboru nemůže být prázdný řetězec.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" není povolený typ souboru",
    "Upload" : "Nahrát",
    "Error" : "Chyba",
    "Error while sharing" : "Chyba při sdílení",
    "Error while unsharing" : "Chyba při rušení sdílení",
    "Error while changing permissions" : "Chyba při změně oprávnění",
    "Shared with you and the group {group} by {owner}" : "S Vámi a skupinou {group} sdílí {owner}",
    "Shared with you by {owner}" : "S Vámi sdílí {owner}",
    "Share with users or groups …" : "Sdílet s uživateli nebo skupinami",
    "Share with users, groups or remote users …" : "Sdílet s uživateli, skupinami nebo vzdálenými uživateli",
    "Share link" : "Sdílet odkaz",
    "The public link will expire no later than {days} days after it is created" : "Veřejný odkaz vyprší nejpozději {days} dní od svého vytvoření",
    "Link" : "Odkaz",
    "Password protect" : "Chránit heslem",
    "Password" : "Heslo",
    "Choose a password for the public link" : "Zadej heslo pro tento veřejný odkaz",
    "Allow editing" : "Povolit úpravy",
    "Email link to person" : "Odeslat osobě odkaz e-mailem",
    "Send" : "Odeslat",
    "Set expiration date" : "Nastavit datum vypršení platnosti",
    "Expiration" : "Konec platnosti",
    "Expiration date" : "Datum vypršení platnosti",
    "This list is maybe truncated - please refine your search term to see more results." : "Tento seznam je možná zkrácený - prosím upřesněte vyhledávací výraz pro více výsledků.",
    "No users or groups found for {search}" : "Nebyli nalezeni žádní členové ani skupiny pro {search}",
    "No users found for {search}" : "Nebyli nalezeni žádní uživatelé pro {search}",
    "Adding user..." : "Přidávám uživatele...",
    "group" : "skupina",
    "remote" : "vzdálený",
    "Resharing is not allowed" : "Sdílení již sdílené položky není povoleno",
    "Error while retrieving shares" : "Chyba při otevírání sdílení",
    "Unshare" : "Zrušit sdílení",
    "notify by email" : "upozornit e-mailem",
    "can share" : "může sdílet",
    "can edit" : "lze upravovat",
    "access control" : "řízení přístupu",
    "create" : "vytvořit",
    "change" : "změnit",
    "delete" : "smazat",
    "Password protected" : "Chráněno heslem",
    "Error unsetting expiration date" : "Chyba při odstraňování data vypršení platnosti",
    "Error setting expiration date" : "Chyba při nastavení data vypršení platnosti",
    "Sending…" : "Odesílání…",
    "Email sent" : "E-mail odeslán",
    "Warning" : "Varování",
    "Add to your Nextcloud" : "Přidat do Nextcloud",
    "This share is password-protected" : "Toto sdílení je chráněno heslem",
    "The password is wrong. Try again." : "Heslo není správné. Zkuste to znovu.",
    "Sort by name" : "Řadit podle jména",
    "Sort by date" : "Řadit podle data",
    "Cancel upload" : "Zrušit odesílání",
    "Album information" : "Informace o albu",
    "File list" : "Seznam souborů",
    "Sorry, this file could not be found." : "Omlouváme se, tento soubor se nepodařilo nalézt.",
    "Reasons might be:" : "Možné důvody:",
    "the wrong file ID was provided" : "bylo zadáno neplatné ID souboru",
    "the file was removed" : "soubor byl odstraněn",
    "the file is corrupt" : "soubor je poškozen",
    "the encryption key is missing" : "chybí šifrovací klíč",
    "Here is the error message returned by the server: " : "Zde je chybová zpráva vrácená serverem:",
    "For more information, please contact your friendly Nextcloud administrator." : "Pokud chcete vědět víc, kontaktujte svého přátelského administrátora  Nextcloudu.",
    "Sorry, but the server could not fulfill your request." : "Omlouváme se, ale server nemohl splnit váš požadavek.",
    "Possible reasons for the problem:" : "Možný důvod problému:",
    "a conflicting app was installed" : "byla nainstalovaná konfliktní aplikace",
    "a required component is missing or was disconnected" : "chybí nebo je odpojena požadovaná část systému",
    "the filesystem is not readable" : "nelze čist ze souborového systému",
    "Sorry, this link doesn't seem to work anymore." : "Omlouváme se, tento odkaz je již nejspíše nefunkční.",
    "the item was removed" : "položka byla odebrána",
    "the link has expired" : "platnost odkazu vypršela",
    "sharing is disabled" : "sdílení je zakázané",
    "For more information, please ask the person who has sent you this link." : "Pro více informací kontaktujte osobu, která vám zaslala tento odkaz.",
    "Picture view" : "Zobrazení obrázku",
    "Gallery view" : "Náhled galerie",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Sdílet s uživateli na jiných serverech za použití jejich sdílených cloud ID username@example.com/cloud",
    "An error occured. Please try again" : "Nastala chyba. Prosím zkuste to znovu",
    "Sending ..." : "Odesílám ..."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
